@@ -4,7 +4,8 @@
 A simple parallel processing API for Python, inspired somewhat by the thread
 module, slightly less by pypar, and slightly less still by pypvm.
 
-Copyright (C) 2005, 2006, 2007, 2008, 2009 Paul Boddie <paul@boddie.org.uk>
+Copyright (C) 2005, 2006, 2007, 2008, 2009, 2013 Paul Boddie <paul@boddie.org.uk>
+Copyright (C) 2013 Yaroslav Halchenko <debian@onerussian.com>
 
 This program is free software; you can redistribute it and/or modify it under
 the terms of the GNU Lesser General Public License as published by the Free
@@ -20,7 +21,7 @@ You should have received a copy of the GNU Lesser General Public License along
 with this program.  If not, see <http://www.gnu.org/licenses/>.
 """
 
-__version__ = "0.5"
+__version__ = "0.5.1"
 
 import os
 import sys
@@ -28,6 +29,8 @@ import select
 import socket
 import platform
 
+from warnings import warn
+
 try:
     import cPickle as pickle
 except ImportError:
@@ -396,8 +399,12 @@ class Exchange:
 
         if self.active():
             for channel in self.ready(timeout):
-                self.store_data(channel)
-                self.start_waiting(channel)
+                try:
+                    self.store_data(channel)
+                    self.start_waiting(channel)
+                except IOError, exc:
+                    self.remove(channel)
+                    warn("Removed channel %r due to IOError: %s" % (channel, exc))
 
         # Or schedule new processes and channels.
 
